==> haskell-unbounded-delays-0.1.1.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unbounded-delays
version: 0.1.1.0
id: unbounded-delays-0.1.1.0-KvddZgm6oGyK2gQebOtQdi
key: unbounded-delays-0.1.1.0-KvddZgm6oGyK2gQebOtQdi
license: BSD3
copyright: 2011-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
homepage: https://github.com/basvandijk/unbounded-delays
synopsis: Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout
abi: e329526f8b00b7fd2bcf260c64aa4058
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/unbounded-delays-0.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/unbounded-delays-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/unbounded-delays-0.1.1.0
hs-libraries: HSunbounded-delays-0.1.1.0-KvddZgm6oGyK2gQebOtQdi
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock
haddock-html: /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unbounded-delays-0.1.1.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unbounded-delays.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unbounded-delays
version: 0.1.1.0
id: unbounded-delays-0.1.1.0-9rdvMSlv4bPE477VFM26yN
key: unbounded-delays-0.1.1.0-9rdvMSlv4bPE477VFM26yN
license: BSD-3-Clause
copyright: 2011-2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
homepage: https://github.com/basvandijk/unbounded-delays
synopsis: Unbounded thread delays and timeouts
description:
    The @threadDelay@ and @timeout@ functions from the @base@ library
    use the bounded @Int@ type for specifying the delay or timeout
    period. This packages provides alternatives which use the
    unbounded @Integer@ type.
category: Concurrency
abi: 5e02d6700e417991a67e203e0b19e096
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Delay Control.Concurrent.Timeout
import-dirs: /usr/lib/ghc-8.4.3/site-local/unbounded-delays-0.1.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/unbounded-delays-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/unbounded-delays-0.1.1.0
hs-libraries: HSunbounded-delays-0.1.1.0-9rdvMSlv4bPE477VFM26yN
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-unbounded-delays/html/unbounded-delays.haddock
haddock-html: /usr/share/doc/haskell-unbounded-delays/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
